﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;

using ThinkGeo.MapSuite;
using ThinkGeo.MapSuite.WebForms;
using ThinkGeo.MapSuite.Drawing;
using ThinkGeo.MapSuite.Layers;
using ThinkGeo.MapSuite.Styles;
using ThinkGeo.MapSuite.Shapes;

namespace SampleWebApp
{
    public partial class Sample : System.Web.UI.Page
    {
        protected void Page_Load(object sender, EventArgs e)
        {
            try
            {
                LoadDefaultMap();
                PlotRoute();

                wfMap.CurrentExtent = new RectangleShape(-180, 90, 180, -90);
            }
            catch (Exception)
            {
                throw new Exception();
            }
        }

        private void LoadDefaultMap()
        {
            try
            {
                if (wfMap.CustomOverlays.Count > 0)
                    wfMap.CustomOverlays.Clear();

                wfMap.MapUnit = GeographyUnit.DecimalDegree;
                wfMap.MapBackground = new GeoSolidBrush(GeoColors.AliceBlue);

                ShapeFileFeatureLayer shpWorldLayer = new ShapeFileFeatureLayer(@"F:\Riyaz\RnD\Web\SampleWebApp\SampleWebApp\MapData\Countries02.shp",@"F:\Riyaz\RnD\Web\SampleWebApp\SampleWebApp\MapData\Countries02.idx",GeoFileReadWriteMode.Read);
                shpWorldLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = new AreaStyle(new GeoPen(GeoColors.LightGreen), new GeoSolidBrush(GeoColors.Transparent));
                shpWorldLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

                LayerOverlay loWorld = new LayerOverlay("WorldOverlay", true, TileType.SingleTile);
                loWorld.Layers.Add("WorldLayer", shpWorldLayer);
                wfMap.CustomOverlays.Add(loWorld);

            }
            catch (Exception)
            {
                throw new Exception();
            }
        }

        private void PlotRoute()
        {
            try
            {
                InMemoryFeatureLayer imRouteLayer = new InMemoryFeatureLayer();
                imRouteLayer.Open();
                imRouteLayer.Columns.Add(new FeatureSourceColumn("FlightID"));
                imRouteLayer.Columns.Add(new FeatureSourceColumn("Type"));

                #region ValueStyle with ClusterPointStyle (Custom)
                Feature ft = null;
                //for (int i = 1; i <= 100; i++)
                //{
                //    ft = new Feature(new PointShape((i / 5), (10+ i)));
                //    ft.Id = i.ToString();
                //    ft.ColumnValues.Add("FlightID", "101");
                //    ft.ColumnValues.Add("Type", "1");
                //    imRouteLayer.InternalFeatures.Add(ft);
                //}

                for (int i = 1; i <= 2000; i++)
                {
                    ft = new Feature(new PointShape((-180 + (i / 5)), 10));
                    ft.Id = i.ToString();
                    ft.ColumnValues.Add("FlightID", "101");
                    ft.ColumnValues.Add("Type", "1");
                    imRouteLayer.InternalFeatures.Add(ft);
                }
                FilterStyle fs_FlightNo = new FilterStyle();
                fs_FlightNo.Name = "101";
                fs_FlightNo.Conditions.Add(new FilterCondition() { Expression = "101", ColumnName = "FlightID" });

                CustomClusterValueStyle cluster = new CustomClusterValueStyle();
                cluster.ColumnName = "Type";

                ValueItem vi = new ValueItem();
                vi.Value = "1";
                vi.DefaultPointStyle = new PointStyle(PointSymbolType.Circle, new GeoSolidBrush(GeoColors.Red), 3);
                cluster.ValueItems.Add("1", vi);

                vi = new ValueItem();
                vi.Value = "2";
                vi.DefaultPointStyle = new PointStyle(PointSymbolType.Circle, new GeoSolidBrush(GeoColors.Blue), 3);
                cluster.ValueItems.Add("2", vi);

                fs_FlightNo.Styles.Add(cluster);
                imRouteLayer.ZoomLevelSet.ZoomLevel01.CustomStyles.Add(fs_FlightNo);
                imRouteLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
                #endregion

                #region Direct ClusterPointStyle
                //CustomClusterPointStyle cluster = new CustomClusterPointStyle(PointSymbolType.Circle, new GeoSolidBrush(GeoColors.Blue), 3);
                //cluster.CellSize = 10;
                //cluster.MinimumFeaturesPerCellToCluster = 1;

                //imRouteLayer.ZoomLevelSet.ZoomLevel01.CustomStyles.Add(cluster);
                //imRouteLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

                //Feature ft = new Feature(new PointShape(10, 10));
                //imRouteLayer.InternalFeatures.Add(ft);

                //ft = new Feature(new PointShape(11, 10));
                //imRouteLayer.InternalFeatures.Add(ft);

                //ft = new Feature(new PointShape(12, 10));
                //imRouteLayer.InternalFeatures.Add(ft);

                //ft = new Feature(new PointShape(13, 10));
                //imRouteLayer.InternalFeatures.Add(ft);

                //ft = new Feature(new PointShape(14, 10));
                //imRouteLayer.InternalFeatures.Add(ft);

                //ft = new Feature(new PointShape(15, 10));
                //imRouteLayer.InternalFeatures.Add(ft);

                //ft = new Feature(new PointShape(16, 10));
                //imRouteLayer.InternalFeatures.Add(ft);

                //ft = new Feature(new PointShape(17, 10));
                //imRouteLayer.InternalFeatures.Add(ft);

                //ft = new Feature(new PointShape(18, 10));
                //imRouteLayer.InternalFeatures.Add(ft);

                //ft = new Feature(new PointShape(19, 10));
                //imRouteLayer.InternalFeatures.Add(ft);

                //ft = new Feature(new PointShape(20, 10));
                //imRouteLayer.InternalFeatures.Add(ft);
                #endregion

                #region ValueStyle with ClusterPointStyle
                //Feature ft = new Feature(new PointShape(10, 10));
                //ft.ColumnValues.Add("Type", "1");
                //imRouteLayer.InternalFeatures.Add(ft);

                //ft = new Feature(new PointShape(11, 10));
                //ft.ColumnValues.Add("Type", "1");
                //imRouteLayer.InternalFeatures.Add(ft);

                //ft = new Feature(new PointShape(12, 10));
                //ft.ColumnValues.Add("Type", "2");
                //imRouteLayer.InternalFeatures.Add(ft);

                //ft = new Feature(new PointShape(13, 10));
                //ft.ColumnValues.Add("Type", "2");
                //imRouteLayer.InternalFeatures.Add(ft);

                //ft = new Feature(new PointShape(14, 10));
                //ft.ColumnValues.Add("Type", "1");
                //imRouteLayer.InternalFeatures.Add(ft);

                //ft = new Feature(new PointShape(15, 10));
                //ft.ColumnValues.Add("Type", "1");
                //imRouteLayer.InternalFeatures.Add(ft);

                //ft = new Feature(new PointShape(16, 10));
                //ft.ColumnValues.Add("Type", "1");
                //imRouteLayer.InternalFeatures.Add(ft);

                //ft = new Feature(new PointShape(17, 10));
                //ft.ColumnValues.Add("Type", "2");
                //imRouteLayer.InternalFeatures.Add(ft);

                //ft = new Feature(new PointShape(18, 10));
                //ft.ColumnValues.Add("Type", "1");
                //imRouteLayer.InternalFeatures.Add(ft);

                //ft = new Feature(new PointShape(19, 10));
                //ft.ColumnValues.Add("Type", "1");
                //imRouteLayer.InternalFeatures.Add(ft);

                //ft = new Feature(new PointShape(20, 10));
                //ft.ColumnValues.Add("Type", "2");
                //imRouteLayer.InternalFeatures.Add(ft);

                //ValueStyle vs = new ValueStyle();
                //vs.ColumnName = "Type";

                //CustomClusterPointStyle cluster = new CustomClusterPointStyle(PointSymbolType.Circle, new GeoSolidBrush(GeoColors.Blue), 5);
                //cluster.CellSize = 10;
                //cluster.MinimumFeaturesPerCellToCluster = 1;
                //cluster.AllFeatures = imRouteLayer.InternalFeatures;
                ////PointStyle cluster = new PointStyle(PointSymbolType.Circle, new GeoSolidBrush(GeoColors.Blue), 3);

                //ValueItem vi = new ValueItem();
                //vi.Value = "1";
                //vi.DefaultPointStyle = cluster;
                //vs.ValueItems.Add(vi);

                ////cluster = new PointStyle(PointSymbolType.Circle, new GeoSolidBrush(GeoColors.Green), 3);

                //cluster = new CustomClusterPointStyle(PointSymbolType.Circle, new GeoSolidBrush(GeoColors.Red), 5);
                //cluster.CellSize = 10;
                //cluster.MinimumFeaturesPerCellToCluster = 1;
                //cluster.AllFeatures = imRouteLayer.InternalFeatures;

                //vi = new ValueItem();
                //vi.Value = "2";
                //vi.DefaultPointStyle = cluster;
                //vs.ValueItems.Add(vi);

                //imRouteLayer.ZoomLevelSet.ZoomLevel01.CustomStyles.Add(vs);
                //imRouteLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;


                #endregion

                LayerOverlay loRoute = new LayerOverlay("RouteOverlay", false, TileType.SingleTile);
                loRoute.Layers.Add("RouteLayer", imRouteLayer);
                wfMap.CustomOverlays.Add(loRoute);
            }
            catch (Exception)
            {
                throw new Exception();
            }
        }
    }
}